@@ -28,4 +28,13 @@ make_exponent<-function(y=NULL,x=NULL){
  
 }
 
+# skip tests on old releases
+
+skip_on_oldrel <- function(version="3.6.3", msg = NULL) {
+  current_version <- utils::packageVersion("base")
+  if (current_version <= version) {
+    msg <- paste("R version",current_version, "not supported. Please upgrade to R>= 3.6.3")
+    testthat::skip(msg)
+  }
+}
 
